import {gql} from '../helpers'
import {   
   actionPromise,
   actionMsgList,
   actionMsgOne
} from '../reducers'
import {   
   actionUploadFile
} from './mediaActions'



export const actionGetMsgsByChat = (chatId, skipCount=0, limitCount=50) => (
   actionPromise('chatMsgs', gql(`query chatMsgs($q: String) {
      MessageFind (query: $q){
         _id
         createdAt
         owner {
            _id
            login
         }
         text

         media {
            url
         }
         forwardWith {
            _id
         }
         replies {
            _id
         }

         replyTo {
            _id
         }
         forwarded {
            _id
         }
      }     
   }`, { 
         q: JSON.stringify([  { "chat. _id": chatId },
                              { 
                                 sort: [{_id: -1}],  
                                 skip: [skipCount], 
                                 limit: [limitCount] 
                              } 
                           ])
      }
   ))
)




export const actionMsgsCount = (chatId) => (
   actionPromise('msgsCount', gql(`query msgsCount($q: String) {
      MessageCount (query: $q)  
   }`, { 
         q: JSON.stringify([ { chat: { _id: chatId } } ])
      }
   ))
)



const actionUpdateMsg = (chatId, text, media, msgId) => (
   actionPromise('updateMsg', gql(`mutation updateMsg($msg: MessageInput) {
      MessageUpsert(message: $msg) {
         _id
         createdAt
         owner {
            _id
            login
         }
         text

         media {
            url
         }
         forwardWith {
            _id
         }
         replies {
            _id
         }

         replyTo {
            _id
         }
         forwarded {
            _id
         }
      }
   }`, { msg: { _id: msgId, text, chat: {_id: chatId}, media } }
   ))
)


// медиа - массив объектов с ид медиа
export const actionSendMsg = (chatId, text, inputName, files, msgId) => (
   async (dispatch, getState) => {

// тут нужно отделить уже залитые файлы от тех которые лежат локально
// локальные залить и получить ид, с залитых просто получить ид
      const media = []
      for (const file of files) {
         if (file.preview.match(/blob/)) {
            let fileObj = await dispatch(actionUploadFile(inputName, file))
            media.push({_id: fileObj?._id})
         } else {
            media.push({})
         }
      }

      await dispatch(actionUpdateMsg(chatId, text, media, msgId))
   }
)



   
   // const actionRemoveMsg = (msgId) => (
   //    actionPromise('removeMsg', gql(`mutation removeMsg($msg: MessageInput) {
   //       MessageDelete(message: $msg) {
   //          _id 
   //       }
   //    }`, { msg: { _id: msgId } }
   //    ))
   // )


