import React from 'react';
import Avatar from '@mui/material/Avatar';

import {backURL}  from '../helpers'
import {connect}  from 'react-redux'


const small = {
  height: '40px', 
  width: '40px'
}

const big = {
  height: '70px', 
  width: '70px'
}


function stringToColor(string) {
  if (!string) {
    return '#' + Math.floor(Math.random()*16777215).toString(16);
  }
  let hash = 0;    
  for (let i = 0; i < string?.length; i += 1) {
    hash = string.charCodeAt(i) + ((hash << 5) - hash);
  }    
  let color = '#'; 
  for (let i = 0; i < 3; i += 1) {
    const value = (hash >> (i * 8)) & 0xff;
    color += `00${value.toString(16)}`.substr(-2);
  }   
  return color;
}

function stringSplit(str) {
  if (!str) {
    return 
  }
  let titleStr = ''
  let letterAmount = 2
  for (const word of str.split(' ')) {
    if (letterAmount <= 0) {
      break
    }
    letterAmount--
    if (word) {
      titleStr += word[0].toUpperCase()
    }  
  }
  return titleStr
}

function stringAvatar(name) { 
  return {
    sx: {
      bgcolor: stringToColor(name),
    },
    children: stringSplit(name)
  };
}


export const UserAvatar = ({  profile, bigSize=false }) => {
  //  console.log(profile)
   
    function getUrl() {
      if (profile.localUrl) {
        return profile.localUrl
      } else if (profile.avatar?.url) {
        return backURL + profile.avatar?.url
      } else {
        return false
      }
    }

   return (
      <>
      {
         getUrl() ?
         <Avatar  sx={ bigSize ? big : small } 
                  alt={profile.nick || profile.login } src={getUrl()} /> :
         <Avatar  sx={ bigSize ? big : small }
                  {...stringAvatar(profile.nick || profile.login)} /> 
      }        
      </>
   ) 
}
export const CUserAvatar = connect( state => ({profile: state.promise.myProfile?.payload || {}}))(UserAvatar)



export const ChatAvatar = ({ chat, bigSize=false }) => {
   
    function getUrl() {
       if (chat.avatar?.url) {
        return backURL + chat.avatar?.url
      } else {
        return false
      }
    }

   return (
      <>
      {
         getUrl() ?
         <Avatar  sx={ bigSize ? big : small } 
                  alt={chat.title } src={getUrl()} /> :
         <Avatar  sx={ bigSize ? big : small }
                  {...stringAvatar(chat.title)} /> 
      }        
      </>
   ) 
}