import * as React from 'react';
import {useState, useEffect} from 'react';

import Avatar from '@mui/material/Avatar';
import Button from '@mui/material/Button';
import CssBaseline from '@mui/material/CssBaseline';
import TextField from '@mui/material/TextField';
import Link from '@mui/material/Link';
import Grid from '@mui/material/Grid';
import Box from '@mui/material/Box';
import LockOutlinedIcon from '@mui/icons-material/LockOutlined';
import Typography from '@mui/material/Typography';
import Container from '@mui/material/Container';
import { createTheme, ThemeProvider } from '@mui/material/styles';

import {connect}  from 'react-redux'
import { actionFullRegister } from "../actions";
import { printStrReq, passReq } from "../helpers";


const RegisterForm = ({minLog='2', onRegister, regError}) => {
   const [login, setLogin] = useState('')
   const [logBlur, setLogBlur] = useState(false)

   const [nick, setNick] = useState('')

   const [pass, setPass] = useState('')
   const [passBlur, setPassBlur] = useState(false)

   const [pass2, setPass2] = useState('')
   const [pass2Blur, setPass2Blur] = useState(false)

   const [wrongAlert, setWrongAlert] = useState(false)

   useEffect(() => {
      if (regError?.status === 'REJECTED') {
         delete localStorage.authToken
         onRegister(login, pass, nick)
      } else if (regError?.payload === null) {
         setWrongAlert(true)
      } else {
         setWrongAlert(false)
      }
   },[regError])


   const handleSubmit = (event) => {
      event.preventDefault()
      onRegister(login, pass, nick)
   }

   return (
      <Box component="form" noValidate onSubmit={handleSubmit} sx={{ mt: 3 }}>

            <Grid container spacing={2}>

               <Grid item xs={12}>
                  <TextField
                     onChange={(e) => {
                           e.target.value = e.target.value.trim()
                           setLogin(e.target.value)
                        }
                     }     
                     onBlur={() => {
                           setLogBlur(true)              
                        }
                     } 
                     onFocus={() => {
                           setLogBlur(false)              
                        }
                     }          
                     error={logBlur ? ((login.length >= minLog ) ? false : true) : false}
                     helperText={printStrReq(login, minLog)}  
                     inputProps={{
                        maxLength: 25
                     }}
                     required
                     fullWidth
                     id="loginReg"
                     label="Логин"
                     name="login"
                     autoComplete="login"
                  />
              </Grid>

              <Grid item xs={12} sm={12}>
                <TextField
                  onChange={(e) => setNick(e.target.value)}
                  autoComplete="nick"
                  name="nick"
                  fullWidth
                  id="nickReg"
                  label="Ник"
                />
              </Grid>


              <Grid item xs={12}>
                  <TextField
                     onChange={(e) => {
                           e.target.value = e.target.value.trim()
                           setPass(e.target.value.trim())
                        }
                     }  
                     onBlur={() => {
                           setPassBlur(true)              
                        }
                     } 
                     onFocus={() => {
                           setPassBlur(false)              
                        }
                     }
                     error={passBlur ? (passReq.checkPass(pass) ? false : true) : false}               
                     helperText={passReq.printPassReq(pass)}            
      
                     inputProps={{
                        maxLength: 100
                      }}
                     required
                     fullWidth
                     name="password"
                     label="Пароль"
                     type="password"
                     id="passwordReg1"
                     autoComplete="new-password"
                  />
              </Grid>

              <Grid item xs={12}>
                  <TextField
                     onChange={(e) => {
                           e.target.value = e.target.value.trim()
                           setPass2(e.target.value.trim())
                        }
                     }  
                     onBlur={() => {
                           setPass2Blur(true)              
                        }
                     } 
                     onFocus={() => {
                           setPass2Blur(false)              
                        }
                     }
                     error={pass2Blur ? (passReq.checkPass(pass2) ? false : true) : false}               
                     helperText={passReq.printPassReq(pass2)}            
      
                     inputProps={{
                        maxLength: 100
                      }}
                     required
                     fullWidth
                     name="password2"
                     label="Повторите пароль"
                     type="password"
                     id="passwordReg2"
                     autoComplete="new-password"
                  />

                  <Typography component="p" variant="body2" mt={1} ml={2} 
                           sx={{fontWeight: 'medium', fontSize: '0.75rem', color: '#d32f2f'}}>
                              {pass2Blur ? (pass === pass2) ? '' : 'Пароли не совпадают' : ''} 
                  </Typography>
                  {  wrongAlert ?
                        <Typography component="p" variant="body2" mt={1} ml={2} 
                           sx={{fontWeight: 'medium', fontSize: '0.75rem', color: '#d32f2f'}}>
                              Пользователь уже существует
                        </Typography> :
                        <></>
                     }

              </Grid>


            </Grid>

            <Button
               disabled={( login.length >= minLog && 
                           passReq.checkPass(pass) && 
                           pass === pass2) ? false : true}

              type="submit"
              fullWidth
              variant="contained"
              sx={{ mt: 2, mb: 2 }}
            >
              Зарегистрироваться
            </Button>


            <Grid container justifyContent="flex-end">
              <Grid item>
                <Link href="/login" variant="body2">
                  Уже есть аккаунт? Войдите
                </Link>
              </Grid>
            </Grid>

          </Box>
   )
}
const CRegisterForm = connect( (state) => ({regError: state.promise.register || {}}), {onRegister: actionFullRegister})(RegisterForm)


const theme = createTheme()
// аргументы - string or bool
export const Register = ({minLog='2', minPass='2', char=false, bigChar=false, number=false}) => {



  return (
    <ThemeProvider theme={theme}>

      <Container component="main" maxWidth="xs">
        <CssBaseline />

        <Box
          sx={{
            marginTop: 8,
            display: 'flex',
            flexDirection: 'column',
            alignItems: 'center',
          }}
        >
          <Avatar sx={{ m: 1, bgcolor: 'secondary.main' }}>
            <LockOutlinedIcon />
          </Avatar>

          <Typography component="h1" variant="h5">
            Регистрация
          </Typography>

          <CRegisterForm minLog={minLog} minPass={minPass} char={char} bigChar={bigChar} number={number}/>
          
        </Box>
      </Container>
    </ThemeProvider>
  )
}
